@@ -119,9 +119,10 @@ class DingtalkPlugin(notify.NotificationPlugin):
         link = self.get_group_url(group)
         message_format = '[%s] %s   %s'
         message = message_format % (event.title, event.message, link)
-        data = {"msgtype": "text",
-                    "text": {
-                        "content": message
+        data = {"msgtype": "markdown",
+                    "markdown": {
+                        "title": event.title,
+                        "text": message
                     }
                 }
         headers = {'Content-type': 'application/json', 'Accept': 'text/plain'}
